==> leadlink_open_api-0.0.31.tar.gz: lib/api_operation_log.dart <==
part of leadlinkopenapi;

// 操作日志
class APIOperationLog {


  // 提交操作日志-水吉水厂
  static commitOperationLogSJSC(String logName,String terminalAddress,String appVersion,{Function() onSucc, Function(String) onFail}) async {

    try {
      // 获取用户
      APIUser.currentUserInfo(onFail: onFail,onSucc: (user) async {

          final userResp = await ParseObject('Users').getObject(user['objectId']);
          ParseObject userObject = userResp.results.first;

              var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
              ..whereEqualTo('name', 'OperationLogSJSC');
              var cntResp = await cntQuery.query();
              ParseObject counter = cntResp.results.first;

              ParseObject item          = ParseObject('OperationLogSJSC');
              item['logName']           = logName ?? '';
              item['terminalAddress']   = terminalAddress ?? '';
              item['isActive']          = true;
              item['user']              = userObject;
              item['appVersion']        = appVersion;
              item['deviceType']        = await APIUtil.fetchDeviceType();
              item['logId']             = counter['next'];

              await item.save();

              counter.setIncrement('next', 1);
              await counter.save();

              if(onSucc != null) onSucc();  

      });
    } 

    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

  // 提交操作日志-生态下泄
  static commitOperationLogFMD(String logName,String terminalAddress,String appVersion,{Function() onSucc, Function(String) onFail}) async {

    try {
      // 获取用户
      APIUser.currentUserInfo(onFail: onFail,onSucc: (user) async {

          final userResp = await ParseObject('Users').getObject(user['objectId']);
          ParseObject userObject = userResp.results.first;

              var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
              ..whereEqualTo('name', 'OperationLogFMD');
              var cntResp = await cntQuery.query();
              ParseObject counter = cntResp.results.first;

              ParseObject item          = ParseObject('OperationLogFMD');
              item['logName']           = logName ?? '';
              item['terminalAddress']   = terminalAddress ?? '';
              item['isActive']          = true;
              item['user']              = userObject;
              item['appVersion']        = appVersion;
              item['deviceType']        = await APIUtil.fetchDeviceType();
              item['logId']             = counter['next'];

              await item.save();

              counter.setIncrement('next', 1);
              await counter.save();

              if(onSucc != null) onSucc();  

      });
    } 

    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

  static queryOperationLogSJSC({Function(List<OperationLogListSJSC> operationLogList) onSucc, Function(String) onFail}) async {

    try {
         var cntQuery = QueryBuilder<OperationLogListSJSC>(OperationLogListSJSC());
         cntQuery.orderByDescending('createdAt');
         var resp = await cntQuery.query();
         if(resp.success == false) {
           if(onFail != null) onFail(APITip.apiFail);
           return;
           }
         if(onSucc != null) onSucc(resp.results.cast<OperationLogListSJSC>());  
    } 
    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

}

==> leadlink_open_api-0.0.32.tar.gz: lib/api_operation_log.dart <==
part of leadlinkopenapi;

// 操作日志
class APIOperationLog {


  // 提交操作日志-水吉水厂
  static commitOperationLogSJSC(String logName,String terminalAddress,String appVersion,{Function() onSucc, Function(String) onFail}) async {

    try {
      // 获取用户
      APIUser.currentUserInfo(onFail: onFail,onSucc: (user) async {

          final userResp = await ParseObject('Users').getObject(user['objectId']);
          ParseObject userObject = userResp.results.first;

              var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
              ..whereEqualTo('name', 'OperationLogSJSC');
              var cntResp = await cntQuery.query();
              ParseObject counter = cntResp.results.first;

              ParseObject item          = ParseObject('OperationLogSJSC');
              item['logName']           = logName ?? '';
              item['terminalAddress']   = terminalAddress ?? '';
              item['isActive']          = true;
              item['user']              = userObject;
              item['appVersion']        = appVersion;
              item['deviceType']        = await APIUtil.fetchDeviceType();
              item['logId']             = counter['next'];

              await item.save();

              counter.setIncrement('next', 1);
              await counter.save();

              if(onSucc != null) onSucc();  

      });
    } 

    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

  // 提交操作日志-生态下泄
  static commitOperationLogFMD(String logName,String terminalAddress,String appVersion,{Function() onSucc, Function(String) onFail}) async {

    try {
      // 获取用户
      APIUser.currentUserInfo(onFail: onFail,onSucc: (user) async {

          final userResp = await ParseObject('Users').getObject(user['objectId']);
          ParseObject userObject = userResp.results.first;

              var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
              ..whereEqualTo('name', 'OperationLogFMD');
              var cntResp = await cntQuery.query();
              ParseObject counter = cntResp.results.first;

              ParseObject item          = ParseObject('OperationLogFMD');
              item['logName']           = logName ?? '';
              item['terminalAddress']   = terminalAddress ?? '';
              item['isActive']          = true;
              item['user']              = userObject;
              item['appVersion']        = appVersion;
              item['deviceType']        = await APIUtil.fetchDeviceType();
              item['logId']             = counter['next'];

              await item.save();

              counter.setIncrement('next', 1);
              await counter.save();

              if(onSucc != null) onSucc();  

      });
    } 

    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

  static queryOperationLogSJSC({Function(List<OperationLogListSJSC> operationLogList) onSucc, Function(String) onFail}) async {

    try {
         var sjscQuery = QueryBuilder<OperationLogListSJSC>(OperationLogListSJSC());
         sjscQuery.orderByDescending('createdAt');
         var resp = await sjscQuery.query();
         if(resp.success == false) {
           if(onFail != null) onFail(APITip.apiFail);
           return;
           }
         if(onSucc != null) onSucc(resp.results.cast<OperationLogListSJSC>());  
    } 
    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

  static queryOperationLogFMD({Function(List<OperationLogListFMD> operationLogList) onSucc, Function(String) onFail}) async {

    try {
         var fmdQuery = QueryBuilder<OperationLogListFMD>(OperationLogListFMD());
         fmdQuery.orderByDescending('createdAt');
         var resp = await fmdQuery.query();
         if(resp.success == false) {
           if(onFail != null) onFail(APITip.apiFail);
           return;
           }
         if(onSucc != null) onSucc(resp.results.cast<OperationLogListFMD>());  
    } 
    catch (e) {
      if(onFail != null) onFail(APITip.apiFail);  
    }

  }

}
